@@ -27,22 +27,22 @@
     for (ianal in which.tab) {
         coocol <- cootot[object$TC[, 1] == ianal, ]
         if (unique.scale) 
-            s.label(cootot, clab = 0, cpoi = 0, sub = object$tab.names[ianal], 
+            s.label(cootot, clabel = 0, cpoint = 0, sub = object$tab.names[ianal], 
                 possub = possub, csub = csub)
-        else s.label(coocol, clab = 0, cpoi = 0, sub = object$tab.names[ianal], 
+        else s.label(coocol, clabel = 0, cpoint = 0, sub = object$tab.names[ianal], 
             possub = possub, csub = csub)
         if (arrow) {
-            s.arrow(coocol, clab = clab, add.p = TRUE)
+            s.arrow(coocol, clabel = clab, add.plot = TRUE)
             label <- FALSE
         }
         if (label) 
-            s.label(coocol, clab = clab, cpoi = cpoi, add.p = TRUE)
+            s.label(coocol, clabel = clab, cpoint = cpoi, add.plot = TRUE)
         if (traject) 
-            s.traject(coocol, clab = 0, add.p = TRUE)
+            s.traject(coocol, clabel = 0, add.plot = TRUE)
         if (!is.null(class)) {
             f1 <- as.factor(class[object$TC[, 1] == ianal])
-            s.class(coocol, f1, clab = clab, cpoi = 2, 
-                pch = 20, axese = FALSE, cell = 0, add.plot = TRUE)
+            s.class(coocol, f1, clabel = clab, cpoint = 2, 
+                pch = 20, axesell = FALSE, cellipse = 0, add.plot = TRUE)
         }
     }
 }
