@@ -83,8 +83,8 @@
   print(object$call)
   
   appel <- as.list(object$call)
-  dudi <- eval(appel$dudi, sys.frame(0))
-  listw <- eval(appel$listw, sys.frame(0))
+  dudi <- eval.parent(appel$dudi)
+  listw <- eval.parent(appel$listw)
   
   ## les scores de l'analyse de base
   nf <- dudi$nf
@@ -149,8 +149,8 @@ print.multispati <- function(x, ...)
     sumry <- array("", c(1, 4), list(1, c("vector", "length", 
         "mode", "content")))
     sumry[1, ] <- c('$eig', length(x$eig), mode(x$eig), 'eigen values')
-    class(sumry) <- "table"
-    print(sumry)
+    
+    print(sumry, quote = FALSE)
     cat("\n")
     sumry <- array("", c(4, 4), list(1:4, c("data.frame", "nrow", "ncol", "content")))
     sumry[1, ] <- c("$c1", nrow(x$c1), ncol(x$c1), "column normed scores")
@@ -158,8 +158,8 @@ print.multispati <- function(x, ...)
     sumry[3, ] <- c("$ls", nrow(x$ls), ncol(x$ls), 'lag vector coordinates')
     sumry[4, ] <- c("$as", nrow(x$as), ncol(x$as), 'inertia axes onto multispati axes')
     
-    class(sumry) <- "table"
-    print(sumry)
+    
+    print(sumry, quote = FALSE)
     cat("other elements: ")
     if (length(names(x)) > 8) 
         cat(names(x)[9:(length(names(x)))], "\n")
@@ -173,7 +173,7 @@ print.multispati <- function(x, ...)
         stop("Use only with 'multispati' objects")
     
     appel <- as.list(x$call)
-    dudi <- eval(appel$dudi, sys.frame(0))
+    dudi <- eval.parent(appel$dudi)
     nf <- x$nfposi + x$nfnega
     if ((nf == 1) || (xax == yax)) {
         sco.quant(x$li[, 1], dudi$tab)
